summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJames E Keenan <jkeenan@cpan.org>2015-01-29 19:21:52 -0500
committerJames E Keenan <jkeenan@cpan.org>2015-01-29 19:21:52 -0500
commitf4fb63c7b74ff0e28cab75889fd6b0947f57d662 (patch)
tree5cdb3b6c63bdc1dd78c2ba237135077656b15892
parenta8ec9917c1913282d626f8c7467e40e55b7f5c97 (diff)
downloadperl-f4fb63c7b74ff0e28cab75889fd6b0947f57d662.tar.gz
Revert "Corrections to spelling and grammatical errors."
This reverts commit 5bf4b3bf13bc4055684a48448b05920845ef7764. On p5p-list, Steve Hay wrote on 2015-01-29: "... these and other changes to Tie-File could break backwards compatibility. The keys of %opt are passed in from user code, so we can't change the expected key from "autodefer_threshhold" to "autodefer_threshold" without also asking users to change their code, which is probably more hassle than it's worth." Parts of the reverted commit will be re-committed from a new patch.
-rw-r--r--dist/Data-Dumper/Changes2
-rw-r--r--dist/Data-Dumper/Dumper.pm4
-rw-r--r--dist/Data-Dumper/Dumper.xs2
-rw-r--r--dist/ExtUtils-CBuilder/Changes2
-rw-r--r--dist/IO/t/io_sock.t2
-rw-r--r--dist/Math-BigInt/t/bigintpm.inc6
-rw-r--r--dist/Math-BigInt/t/upgrade.inc2
-rw-r--r--dist/Module-CoreList/Changes2
-rw-r--r--dist/Safe/Changes2
-rw-r--r--dist/Storable/ChangeLog2
-rw-r--r--dist/Storable/Storable.pm2
-rw-r--r--dist/Storable/Storable.xs2
-rw-r--r--dist/Storable/t/attach_errors.t2
-rw-r--r--dist/Tie-File/lib/Tie/File.pm28
-rw-r--r--dist/Tie-File/t/00_version.t2
-rw-r--r--dist/Tie-File/t/31_autodefer.t4
-rw-r--r--dist/threads-shared/t/hv_refs.t2
17 files changed, 34 insertions, 34 deletions
diff --git a/dist/Data-Dumper/Changes b/dist/Data-Dumper/Changes
index eca3bb9995..1f319227a1 100644
--- a/dist/Data-Dumper/Changes
+++ b/dist/Data-Dumper/Changes
@@ -328,7 +328,7 @@ C<require 5.002>.
MLDBM example removed (as its own module, it has a separate CPAN
reality now).
-Fixed bugs in handling keys with weird characters. Perl can be
+Fixed bugs in handling keys with wierd characters. Perl can be
tripped up in its implicit quoting of the word before '=>'. The
fix: C<Data::Dumper::Purity>, when set, always triggers quotes
around hash keys.
diff --git a/dist/Data-Dumper/Dumper.pm b/dist/Data-Dumper/Dumper.pm
index f9e6a1e5f9..f426f3fb5f 100644
--- a/dist/Data-Dumper/Dumper.pm
+++ b/dist/Data-Dumper/Dumper.pm
@@ -10,7 +10,7 @@
package Data::Dumper;
BEGIN {
- $VERSION = '2.157'; # Don't forget to set version and release
+ $VERSION = '2.156'; # Don't forget to set version and release
} # date in POD below!
#$| = 1;
@@ -1419,7 +1419,7 @@ modify it under the same terms as Perl itself.
=head1 VERSION
-Version 2.157 (January 28 2015)
+Version 2.156 (January 20 2014)
=head1 SEE ALSO
diff --git a/dist/Data-Dumper/Dumper.xs b/dist/Data-Dumper/Dumper.xs
index 98b013baff..70b0c9281e 100644
--- a/dist/Data-Dumper/Dumper.xs
+++ b/dist/Data-Dumper/Dumper.xs
@@ -440,7 +440,7 @@ DD_dump(pTHX_ SV *val, const char *name, STRLEN namelen, SV *retval, HV *seenhv,
if (!val)
return 0;
- /* If the output buffer has less than some arbitrary amount of space
+ /* If the ouput buffer has less than some arbitrary amount of space
remaining, then enlarge it. For the test case (25M of output),
*1.1 was slower, *2.0 was the same, so the first guess of 1.5 is
deemed to be good enough. */
diff --git a/dist/ExtUtils-CBuilder/Changes b/dist/ExtUtils-CBuilder/Changes
index 89301c6b55..fab9a9d083 100644
--- a/dist/ExtUtils-CBuilder/Changes
+++ b/dist/ExtUtils-CBuilder/Changes
@@ -381,7 +381,7 @@ Revision history for Perl extension ExtUtils::CBuilder.
somehow never got into this copy. [Steve Hay]
- Added a new 'defines' parameter to compile(), which gives a
- platform-independent way to specify various -Dfoo=bar (or the
+ platform-independant way to specify various -Dfoo=bar (or the
equivalent) compiler defines. [Randy W. Sims]
0.14 Mon Sep 19 13:40:37 CDT 2005
diff --git a/dist/IO/t/io_sock.t b/dist/IO/t/io_sock.t
index c9c443beb8..0202d70964 100644
--- a/dist/IO/t/io_sock.t
+++ b/dist/IO/t/io_sock.t
@@ -210,7 +210,7 @@ if ( $^O eq 'qnx' ) {
}
### TEST 15
-### Set up some data to be transferred between the server and
+### Set up some data to be transfered between the server and
### the client. We'll use own source code ...
#
local @data;
diff --git a/dist/Math-BigInt/t/bigintpm.inc b/dist/Math-BigInt/t/bigintpm.inc
index c3e815cb60..0d47f6d79d 100644
--- a/dist/Math-BigInt/t/bigintpm.inc
+++ b/dist/Math-BigInt/t/bigintpm.inc
@@ -1135,7 +1135,7 @@ abc:abc:NaN
+1:+32:4294967296
+1:+48:281474976710656
+8:-2:NaN
-# exercise base 10
+# excercise base 10
+12345:4:10:123450000
-1234:0:10:-1234
+1234:0:10:1234
@@ -1153,7 +1153,7 @@ abc:abc:NaN
+4294967296:+32:1
+281474976710656:+48:1
+2:-2:NaN
-# exercise base 10
+# excercise base 10
-1234:0:10:-1234
+1234:0:10:1234
+200:2:10:2
@@ -1585,7 +1585,7 @@ inf:0:inf,inf
96969696969696969696969696969678787878626262626262626262626262:484848484848484848484848486666666666666689898989898989898989:199,484848484848484848484848123012121211954972727272727272727451
# bug in v1.76
1267650600228229401496703205375:1267650600228229401496703205376:0,1267650600228229401496703205375
-# exercise shortcut for numbers of the same length in div
+# excercise shortcut for numbers of the same length in div
999999999999999999999999999999999:999999999999999999999999999999999:1,0
999999999999999999999999999999999:888888888888888888888888888888888:1,111111111111111111111111111111111
999999999999999999999999999999999:777777777777777777777777777777777:1,222222222222222222222222222222222
diff --git a/dist/Math-BigInt/t/upgrade.inc b/dist/Math-BigInt/t/upgrade.inc
index ef0a6eaf5a..5516fa735c 100644
--- a/dist/Math-BigInt/t/upgrade.inc
+++ b/dist/Math-BigInt/t/upgrade.inc
@@ -567,7 +567,7 @@ abc:abc:NaN
+1:+32:4294967296
+1:+48:281474976710656
+8:-2:NaN
-# exercise base 10
+# excercise base 10
+12345:4:10:123450000
-1234:0:10:-1234
+1234:0:10:1234
diff --git a/dist/Module-CoreList/Changes b/dist/Module-CoreList/Changes
index 12fe65ecba..3082f055e4 100644
--- a/dist/Module-CoreList/Changes
+++ b/dist/Module-CoreList/Changes
@@ -52,7 +52,7 @@
3.06 Thu Feb 20 2014
- updated for 5.19.9
- fix Module::CoreList::is_core default perl version
- - fix Module::CoreList::is_core version comparison
+ - fix Module::CoreList::is_core version comparision
3.05
- Prepared for v5.19.9
diff --git a/dist/Safe/Changes b/dist/Safe/Changes
index 8c903950e9..a7071958bb 100644
--- a/dist/Safe/Changes
+++ b/dist/Safe/Changes
@@ -163,7 +163,7 @@
2.09 Sun Oct 6 14:12:40 CEST 2002
- Upgraded the Makefile.PL to install Safe.pm to the correct place.
- - Made it work on 5.6 at least, maybe even on 5.005?
+ - Made it work on 5.6 atleast, maybe even on 5.005?
2.08 Sat Oct 5 18:05:32 CEST 2002
- First CPAN release, prompted by bug number 17744 on rt.perl.org.
diff --git a/dist/Storable/ChangeLog b/dist/Storable/ChangeLog
index cbfdbabb83..4df921efd9 100644
--- a/dist/Storable/ChangeLog
+++ b/dist/Storable/ChangeLog
@@ -209,7 +209,7 @@ Fri Jun 7 23:55:41 BST 2002 Nicholas Clark
The bug was introduced as development perl change 16442 (on
2002/05/07), so has been present since 2.00.
Patches to introduce more regression tests to reduce the chance of
- a reoccurrence of this sort of goof are always welcome.
+ a reoccurence of this sort of goof are always welcome.
Thu May 30 20:31:08 BST 2002 Nicholas Clark <nick@ccl4.org>
diff --git a/dist/Storable/Storable.pm b/dist/Storable/Storable.pm
index 9d8b621c9c..f5afadaab9 100644
--- a/dist/Storable/Storable.pm
+++ b/dist/Storable/Storable.pm
@@ -22,7 +22,7 @@ package Storable; @ISA = qw(Exporter);
use vars qw($canonical $forgive_me $VERSION);
-$VERSION = '2.53';
+$VERSION = '2.52';
BEGIN {
if (eval { local $SIG{__DIE__}; require Log::Agent; 1 }) {
diff --git a/dist/Storable/Storable.xs b/dist/Storable/Storable.xs
index 39f35653a0..7d27275f41 100644
--- a/dist/Storable/Storable.xs
+++ b/dist/Storable/Storable.xs
@@ -3720,7 +3720,7 @@ undef_special_case:
* Write magic number and system information into the file.
* Layout is <magic> <network> [<len> <byteorder> <sizeof int> <sizeof long>
* <sizeof ptr>] where <len> is the length of the byteorder hexa string.
- * All size and lengths are written as single characters here.
+ * All size and lenghts are written as single characters here.
*
* Note that no byte ordering info is emitted when <network> is true, since
* integers will be emitted in network order in that case.
diff --git a/dist/Storable/t/attach_errors.t b/dist/Storable/t/attach_errors.t
index 6cebd9735d..c163ca04fa 100644
--- a/dist/Storable/t/attach_errors.t
+++ b/dist/Storable/t/attach_errors.t
@@ -234,7 +234,7 @@ use Storable ();
isa_ok( $thawed->[1], 'My::GoodAttach::MultipleReferences' );
is($thawed->[0], $thawed->[1], 'References to the same object are attached properly');
- is($thawed->[1]{id}, $obj->{id}, 'Object with multiple references attached properly');
+ is($thawed->[1]{id}, $obj->{id}, 'Object with multiple references attchached properly');
package My::GoodAttach::MultipleReferences;
diff --git a/dist/Tie-File/t/00_version.t b/dist/Tie-File/t/00_version.t
index 3a404ff38c..1bd714ec0c 100644
--- a/dist/Tie-File/t/00_version.t
+++ b/dist/Tie-File/t/00_version.t
@@ -2,7 +2,7 @@
print "1..1\n";
-my $testversion = "1.02";
+my $testversion = "1.01";
use Tie::File;
if ($Tie::File::VERSION != $testversion) {
diff --git a/dist/Tie-File/t/31_autodefer.t b/dist/Tie-File/t/31_autodefer.t
index e7af0ad6ed..ea929a4097 100644
--- a/dist/Tie-File/t/31_autodefer.t
+++ b/dist/Tie-File/t/31_autodefer.t
@@ -28,7 +28,7 @@ print $o ? "ok $N\n" : "not ok $N\n";
$N++;
# I am an undocumented feature
-$o->{autodefer_filelen_threshold} = 0;
+$o->{autodefer_filelen_threshhold} = 0;
# Normally autodeferring only works on large files. This disables that.
# (3-22) Deferred storage
@@ -111,7 +111,7 @@ my $BUF = 20;
$o = tie @a, 'Tie::File', $file, autodefer => 0;
die $! unless $o;
# I am an undocumented feature
-$o->{autodefer_filelen_threshold} = 0;
+$o->{autodefer_filelen_threshhold} = 0;
# Normally autodeferring only works on large files. This disables that.
# (57-59) Did the autodefer => 0 option work?
diff --git a/dist/threads-shared/t/hv_refs.t b/dist/threads-shared/t/hv_refs.t
index a2d2206950..ecefdc6d5b 100644
--- a/dist/threads-shared/t/hv_refs.t
+++ b/dist/threads-shared/t/hv_refs.t
@@ -63,7 +63,7 @@ ok(8, threads::shared::_id($$gg) == threads::shared::_id($$gg2),
sprintf("Check we get the same thing (%x vs %x)",
threads::shared::_id($$gg),threads::shared::_id($$gg2)));
ok(9, $$gg eq $$gg2, "And check the values are the same");
-ok(10, keys %foo == 0, "And make sure we really have deleted the values");
+ok(10, keys %foo == 0, "And make sure we realy have deleted the values");
{
my (%hash1, %hash2);
share(%hash1);
diff --git a/dist/Tie-File/lib/Tie/File.pm b/dist/Tie-File/lib/Tie/File.pm
index 1f71531f12..df8a197867 100644
--- a/dist/Tie-File/lib/Tie/File.pm
+++ b/dist/Tie-File/lib/Tie/File.pm
@@ -7,14 +7,14 @@ use Fcntl 'O_CREAT', 'O_RDWR', 'LOCK_EX', 'LOCK_SH', 'O_WRONLY', 'O_RDONLY';
sub O_ACCMODE () { O_RDONLY | O_RDWR | O_WRONLY }
-$VERSION = "1.02";
+$VERSION = "1.01";
my $DEFAULT_MEMORY_SIZE = 1<<21; # 2 megabytes
-my $DEFAULT_AUTODEFER_THRESHOLD = 3; # 3 records
-my $DEFAULT_AUTODEFER_FILELEN_THRESHOLD = 65536; # 16 disk blocksful
+my $DEFAULT_AUTODEFER_THRESHHOLD = 3; # 3 records
+my $DEFAULT_AUTODEFER_FILELEN_THRESHHOLD = 65536; # 16 disk blocksful
my %good_opt = map {$_ => 1, "-$_" => 1}
qw(memory dw_size mode recsep discipline
- autodefer autochomp autodefer_threshold concurrent);
+ autodefer autochomp autodefer_threshhold concurrent);
sub TIEARRAY {
if (@_ % 2 != 0) {
@@ -62,10 +62,10 @@ sub TIEARRAY {
$opts{autodefer} = 1 unless defined $opts{autodefer};
$opts{autodeferring} = 0; # but is not initially active
$opts{ad_history} = [];
- $opts{autodefer_threshold} = $DEFAULT_AUTODEFER_THRESHOLD
- unless defined $opts{autodefer_threshold};
- $opts{autodefer_filelen_threshold} = $DEFAULT_AUTODEFER_FILELEN_THRESHOLD
- unless defined $opts{autodefer_filelen_threshold};
+ $opts{autodefer_threshhold} = $DEFAULT_AUTODEFER_THRESHHOLD
+ unless defined $opts{autodefer_threshhold};
+ $opts{autodefer_filelen_threshhold} = $DEFAULT_AUTODEFER_FILELEN_THRESHHOLD
+ unless defined $opts{autodefer_filelen_threshhold};
$opts{offsets} = [0];
$opts{filename} = $file;
@@ -1100,7 +1100,7 @@ sub _old_flush {
@{$self->{deferred}}{$first_rec .. $last_rec});
}
- $self->_discard; # clear out deferred-write-cache
+ $self->_discard; # clear out defered-write-cache
}
sub _flush {
@@ -1133,7 +1133,7 @@ sub _flush {
}
$self->_mtwrite(@args); # write multiple record groups
- $self->_discard; # clear out deferred-write-cache
+ $self->_discard; # clear out defered-write-cache
$self->_oadjust(@adjust);
}
@@ -1201,7 +1201,7 @@ sub autodefer {
# Now, what does the ad_history mean, and what is this function doing?
# Essentially, the idea is to enable autodeferring when we see that the
# user has made three consecutive STORE calls to three consecutive records.
-# ("Three" is actually ->{autodefer_threshold}.)
+# ("Three" is actually ->{autodefer_threshhold}.)
# A STORE call for record #$n inserts $n into the autodefer history,
# and if the history contains three consecutive records, we enable
# autodeferment. An ad_history of [X, Y] means that the most recent
@@ -1220,7 +1220,7 @@ sub _annotate_ad_history {
my ($self, $n) = @_;
return unless $self->{autodefer}; # feature is disabled
return if $self->{defer}; # already in explicit defer mode
- return unless $self->{offsets}[-1] >= $self->{autodefer_filelen_threshold};
+ return unless $self->{offsets}[-1] >= $self->{autodefer_filelen_threshhold};
local *H = $self->{ad_history};
if ($n eq 'CLEAR') {
@@ -1232,7 +1232,7 @@ sub _annotate_ad_history {
} else { # @H == 2
if ($H[1] == $n-1) { # another consecutive record
$H[1]++;
- if ($H[1] - $H[0] + 1 >= $self->{autodefer_threshold}) {
+ if ($H[1] - $H[0] + 1 >= $self->{autodefer_threshhold}) {
$self->{autodeferring} = 1;
}
} else { # nonconsecutive- erase and start over
@@ -1562,7 +1562,7 @@ sub lookup {
# $self->[MISS]++ if $self->[STAT][$key]++ == 0;
# $self->[REQ]++;
# my $hit_rate = 1 - $self->[MISS] / $self->[REQ];
# # Do some testing to determine this threshold
# $#$self = STAT - 1 if $hit_rate > 0.20;
# }
@@ -1562,7 +1562,7 @@ sub lookup {
# $self->[REQ]++;
# my $hit_rate = 1 - $self->[MISS] / $self->[REQ];
-# # Do some testing to determine this threshold
+# # Do some testing to determine this threshhold
# $#$self = STAT - 1 if $hit_rate > 0.20;
# }